@@ -1,3 +1,6 @@
+import inspect
+import os
+
 import jug.compound
 import jug.mapreduce
 import numpy as np
@@ -7,6 +10,11 @@ from jug.compound import CompoundTask
 from jug.tests.test_mapreduce import mapper, reducer, dfs_run
 from jug.tests.task_reset import task_reset
 
+
+_jugdir = os.path.abspath(inspect.getfile(inspect.currentframe()))
+_jugdir = os.path.join(os.path.dirname(_jugdir), 'jugfiles')
+
+
 @task_reset
 def test_compound():
     jug.task.Task.store = dict_store()
@@ -21,9 +29,10 @@ def test_compound():
 
 @task_reset
 def test_w_barrier():
-    store, space = jug.jug.init('jug/tests/jugfiles/compound_wbarrier.py', 'dict_store')
+    jugfile = os.path.join(_jugdir, 'compound_wbarrier.py')
+    store, space = jug.jug.init(jugfile, 'dict_store')
     simple_execute()
-    store, space = jug.jug.init('jug/tests/jugfiles/compound_wbarrier.py', store)
+    store, space = jug.jug.init(jugfile, store)
     simple_execute()
     assert 'sixteen' in space
     assert space['sixteen'].result == 16
@@ -31,22 +40,24 @@ def test_w_barrier():
 
 @task_reset
 def test_non_simple():
-    store, space = jug.jug.init('jug/tests/jugfiles/compound_nonsimple.py', 'dict_store')
+    jugfile = os.path.join(_jugdir, 'compound_nonsimple.py')
+    store, space = jug.jug.init(jugfile, 'dict_store')
     simple_execute()
-    store, space = jug.jug.init('jug/tests/jugfiles/compound_nonsimple.py', store)
+    store, space = jug.jug.init(jugfile, store)
     simple_execute()
-    store, space = jug.jug.init('jug/tests/jugfiles/compound_nonsimple.py', store)
+    store, space = jug.jug.init(jugfile, store)
     simple_execute()
     assert 'sixteen' in space
     assert space['sixteen'].result == 16
 
 @task_reset
 def test_compound_jugfile():
-    store, space = jug.jug.init('jug/tests/jugfiles/compound.py', 'dict_store')
+    jugfile = os.path.join(_jugdir, 'compound.py')
+    store, space = jug.jug.init(jugfile, 'dict_store')
     simple_execute()
     assert 'sixteen' in space
     assert space['sixteen'].result == 16
-    store, space = jug.jug.init('jug/tests/jugfiles/compound.py', store)
+    store, space = jug.jug.init(jugfile, store)
     assert 'sixteen' in space
     assert space['sixteen'].result == 16
 
@@ -57,12 +68,13 @@ def test_debug():
     from jug.options import default_options
     options = default_options.copy()
     options.debug = True
+    jugfile = os.path.join(_jugdir, 'compound.py')
 
-    store, space = jug.jug.init('jug/tests/jugfiles/compound.py', 'dict_store')
+    store, space = jug.jug.init(jugfile, 'dict_store')
     execution_loop(alltasks, options)
     assert 'sixteen' in space
     assert space['sixteen'].result == 16
-    store, space = jug.jug.init('jug/tests/jugfiles/compound.py', store)
+    store, space = jug.jug.init(jugfile, store)
     assert 'sixteen' in space
     assert space['sixteen'].result == 16
 
