@@ -1,9 +1,7 @@
 import inspect
 import os
 
-from nose.tools import with_setup
 import jug.task
-from jug.backends.dict_store import dict_store
 from jug.tests.task_reset import task_reset
 from jug.tests.utils import simple_execute
 
@@ -13,14 +11,6 @@ _jugdir = os.path.join(os.path.dirname(_jugdir), 'jugfiles')
 
 
 Task = jug.task.Task
-jug.task.Task.store = dict_store()
-def _setup():
-    jug.task.Task.store = dict_store()
-
-def _teardown():
-    jug.task.alltasks = []
-
-task_reset = with_setup(_setup, _teardown)
 
 def add1(x):
     return x + 1
