@@ -23,7 +23,7 @@
 
 import os
 
-from .task import Task, Tasklet, value
+from .task import Task, TaskGenerator, Tasklet, value
 
 __all__ = [
     'timed_path',
@@ -39,10 +39,20 @@ def identity(x):
     x = identity(x)
 
     `identity` implements the identity function as a Task
-    (i.e., value(identity(x)) == x)
+    (i.e., ``value(identity(x)) == x``)
 
-    This seems pointless, but if x is, for example, a very large list, then
-    using the output of this function might be much faster than using x directly.
+    This seems pointless, but if ``x`` is, for example, a very large list, then
+    using this function might speed up some computations. Consider::
+
+        large = list(range(100000))
+        large = jug.utils.identity(large)
+        for i in range(100):
+            Task(process, large, i)
+
+    This way the list ``large`` is going to get hashed just once. Without the
+    call to ``jug.utils.identity``, it would get hashed at each loop iteration.
+
+    https://jug.readthedocs.io/en/latest/utilities.html#identity
 
     Parameters
     ----------
@@ -144,3 +154,30 @@ def timed_path(path):
     '''
     return CustomHash(path, hash_with_mtime_size)
 
+@TaskGenerator
+def jug_execute(args, check_exit=True, run_after=None):
+    '''jug_execute(args, check_exit=True, run_after=None)
+
+    Wrapper around ``subprocess.call()``
+
+    Examples
+    --------
+
+    ::
+
+        create_input_tmp = jug_execute(['cp', 'input', 'input.tmp'])
+        jug_execute(['wc', '-l', 'input.tmp'], run_after=create_input_tmp)
+
+    Parameters
+    ----------
+    args : list of str
+    check_exit : boolean, optional
+        If true (default), then a non-zero exit results in an exception
+    run_after : any, optional
+        This is unused by the function, but can be used to order different
+        calls to jug_execute
+    '''
+    import subprocess
+    ret = subprocess.call(args)
+    if check_exit and ret != 0:
+        raise SystemError("Error in system")
